@@ -45,13 +45,14 @@
 #include <math.h>
 #include <time.h>
 
-#include "slideshow.h"
-#include "slideshow.moc"
-
 #ifdef HAVE_KEXIV2
 #include <libkexiv2/kexiv2.h>
 #endif
 
+#include "slideshow.h"
+#include "slideshow.moc"
+
+
 #define SLIDESHOW_VERSION "2.3.0"
 static const char version[] = SLIDESHOW_VERSION;
 static const char description[] = I18N_NOOP("KSlideshow");
@@ -99,9 +100,9 @@ kSlideShowSaver::kSlideShowSaver( WId id ): KScreenSaver(id)
   mEffect = NULL;
   mNumEffects = 0;
   mIntArray = NULL;
+  readConfig();
   registerEffects();
 
-  readConfig();
   initNextScreen();
 
   mFileIdx = 0;
@@ -158,10 +159,12 @@ void kSlideShowSaver::readConfig()
   mShowRandom = config.readEntry("ShowRandom", true);
   mZoomImages = config.readEntry("ZoomImages", false);
   mPrintName = config.readEntry("PrintName", true);
-  mDirectory = config.readPathEntry("Directory", KGlobal::dirs()->findDirs("wallpaper", "").last());
+  mPrintPath = config.readEntry("PrintPath", false);
+  mDirectory = config.readPathEntry("Directory", KGlobal::dirs()->findDirs("wallpaper", QLatin1String( "" )).last());
   mDelay = config.readEntry("Delay", 10) * 1000;
   mSubdirectory = config.readEntry("SubDirectory", false);
   mRandomPosition = config.readEntry("RandomPosition", false);
+  mEffectsEnabled = config.readEntry("EffectsEnabled", true);
 
   loadDirectory();
 }
@@ -170,6 +173,12 @@ void kSlideShowSaver::readConfig()
 //----------------------------------------------------------------------------
 void kSlideShowSaver::registerEffects()
 {
+  if (!mEffectsEnabled)
+  {
+    mEffectList = 0;
+    return;
+  }
+
   int i = 0;
 
   mEffectList = new EffectMethod[64];
@@ -720,13 +729,20 @@ void kSlideShowSaver::paintEvent(QPaintEvent *)
   {
     loadNextImage();
     createNextScreen();
+    if (mNumEffects == 0)
+    {
+      showNextScreen();
+      tmout = -1;
+    }
+    else
+    {
+      if (mNumEffects > 1) i = KRandom::random() % mNumEffects;
+      else i = 0;
 
-    if (mNumEffects > 1) i = KRandom::random() % mNumEffects;
-    else i = 0;
-
-    mEffect = mEffectList[i];
-    mEffectRunning = true;
-    tmout = (this->*mEffect)(true);
+      mEffect = mEffectList[i];
+      mEffectRunning = true;
+      tmout = (this->*mEffect)(true);
+    }
   }
   if (tmout <= 0)
   {
@@ -886,7 +902,7 @@ nexttry:
   exiv.rotateExifQImage(mImage, exiv.getImageOrientation());
 #endif
 
-  mImageName = QFileInfo(fname).baseName();
+  mImageName = mPrintPath ? fname : QFileInfo(fname).completeBaseName();
 }
 
 
@@ -912,7 +928,7 @@ void kSlideShowSaver::traverseDirectory(const QString &dirName)
   QFileInfoList::Iterator it = fileinfolist.begin();
   while ( it != fileinfolist.end())
   {
-     if (it->fileName() == "." || it->fileName() == "..")
+     if (it->fileName() == QLatin1String( "." ) || it->fileName() == QLatin1String( ".." ))
      {
         ++it;
         continue;
@@ -954,10 +970,10 @@ kSlideShowSetup::kSlideShowSetup(QWidget *aParent)
   mSaver = new kSlideShowSaver(cfg->mPreview->winId());
 
   cfg->mDirChooser->setMode(KFile::Directory | KFile::ExistingOnly);
-  connect(cfg->mDirChooser, SIGNAL(returnPressed(const QString &)),
-      SLOT(slotDirSelected(const QString &)));
-  connect(cfg->mDirChooser, SIGNAL(urlSelected(const KUrl &)),
-      SLOT(slotDirSelected(const KUrl &)));
+  connect(cfg->mDirChooser, SIGNAL(returnPressed(QString)),
+      SLOT(slotDirSelected(QString)));
+  connect(cfg->mDirChooser, SIGNAL(urlSelected(KUrl)),
+      SLOT(slotDirSelected(KUrl)));
   connect(this,SIGNAL(okClicked()),this,SLOT(slotOk()));
   connect(this,SIGNAL(helpClicked()),this,SLOT(slotHelp()));
   readSettings();
@@ -976,11 +992,13 @@ void kSlideShowSetup::readSettings()
     cfg->mCbxRandom->setChecked(config.readEntry("ShowRandom", true));
     cfg->mCbxZoom->setChecked(config.readEntry("ZoomImages", false));
     cfg->mCbxShowName->setChecked(config.readEntry("PrintName", true));
+    cfg->mCbxShowPath->setChecked(config.readEntry("PrintPath", false));
     cfg->mDelay->setValue(config.readEntry("Delay", 20));
     cfg->mDelay->setSuffix(ki18np(" second", " seconds"));
-    cfg->mDirChooser->setPath(config.readPathEntry("Directory", QString()));
+    cfg->mDirChooser->setUrl(KUrl(config.readPathEntry("Directory", QString())));
     cfg->mCbxSubdirectory->setChecked(config.readEntry("SubDirectory", false));
     cfg->mCbxRandomPosition->setChecked(config.readEntry("RandomPosition", false));
+    //cfg->mCbxEffectsEnabled->setChecked(config.readEntry("EffectsEnabled", true));
 }
 
 
@@ -992,10 +1010,12 @@ void kSlideShowSetup::writeSettings()
   config.writeEntry("ShowRandom", cfg->mCbxRandom->isChecked());
   config.writeEntry("ZoomImages", cfg->mCbxZoom->isChecked());
   config.writeEntry("PrintName",  cfg->mCbxShowName->isChecked());
+  config.writeEntry("PrintPath",  cfg->mCbxShowPath->isChecked());
   config.writeEntry("Delay", cfg->mDelay->value());
   config.writePathEntry("Directory", cfg->mDirChooser->url().path());
   config.writeEntry("SubDirectory", cfg->mCbxSubdirectory->isChecked());
   config.writeEntry("RandomPosition", cfg->mCbxRandomPosition->isChecked());
+  //config.writeEntry("EffectsEnabled", cfg->mCbxEffectsEnabled->isChecked());
 
   config.sync();
 
